@@ -30,7 +30,7 @@ pub struct DeepObject<'s, F>
 where
     F: for<'a> EncodingFn<'a>,
 {
-    output: String,
+    output: &'s mut String,
     name: &'s str,
     encoder: F,
     state: State,
@@ -45,7 +45,7 @@ where
     /// # Example
     ///
     /// ```
-    /// use querylizer::{escape_query, DeepObject};
+    /// use querylizer::{encode_query, DeepObject};
     /// #[derive(serde::Serialize)]
     /// struct A {
     ///     a: i32,
@@ -55,7 +55,7 @@ where
     /// let s = DeepObject::to_string(
     ///     "value",
     ///     &a,
-    ///     escape_query
+    ///     encode_query
     /// ).unwrap();
     /// assert_eq!(s, "value[a]=12&value[b]=%23hello".to_owned());
     /// ```
@@ -67,14 +67,15 @@ where
     where
         T: Serialize,
     {
+        let mut output = String::new();
         let mut serializer = DeepObject {
-            output: String::new(),
+            output: &mut output,
             name,
             encoder,
             state: State::Outer,
         };
         value.serialize(&mut serializer)?;
-        Ok(serializer.output)
+        Ok(output)
     }
 
     /// Append a `deepObject` value onto an existing string to be used for web requests.
@@ -82,27 +83,28 @@ where
     /// # Example
     ///
     /// ```
-    /// use querylizer::{escape_query, DeepObject};
+    /// use querylizer::{encode_query, DeepObject};
     /// #[derive(serde::Serialize)]
     /// struct A {
     ///     a: i32,
     ///     b: String,
     /// }
     /// let a = A { a: 12, b: "#hello".to_owned() };
-    /// let s = DeepObject::extend(
-    ///     "https://example.com/v1/?".to_owned(),
+    /// let mut s = "https://example.com/v1/?".to_owned();
+    /// DeepObject::extend(
+    ///     &mut s,
     ///     "value",
     ///     &a,
-    ///     escape_query
+    ///     encode_query
     /// ).unwrap();
     /// assert_eq!(s, "https://example.com/v1/?value[a]=12&value[b]=%23hello".to_owned());
     /// ```
     pub fn extend<T>(
-        output: String,
+        output: &mut String,
         name: &str,
         value: &T,
         encoder: F,
-    ) -> Result<String, QuerylizerError>
+    ) -> Result<(), QuerylizerError>
     where
         T: Serialize,
     {
@@ -113,7 +115,7 @@ where
             state: State::Outer,
         };
         value.serialize(&mut serializer)?;
-        Ok(serializer.output)
+        Ok(())
     }
 }
 
